@@ -20,17 +20,16 @@ done
 
 ORIG_SRC_DIR=${PACKAGE_NAME}
 DEB_SRC_DIR=${PACKAGE_NAME}-${VERSION}+dfsg
-DEB_SRC_TAR=${PACKAGE_NAME}_${VERSION}+dfsg.orig.tar.gz
+DEB_SRC_TAR=${PACKAGE_NAME}_${VERSION}+dfsg.orig.tar.xz
 
 cd ${TMP_DIR}
 tar -axf ${ORIG_SRC_TAR}
 mv ${ORIG_SRC_DIR} ${DEB_SRC_DIR}
 cd ${DEB_SRC_DIR}
-rm -rf components/aggpas
+rm -rf components/aggpas/gpc
 rm -rf components/mpaslex
 rm -rf debian
 rm -rf lcl/interfaces/carbon
-rm -rf packager/globallinks/aggpas*.lpl
 find -name Makefile.fpc -execdir sh -c 'rm $(basename {} .fpc)' ';'
 find '(' -name '*.icns' -or -name '*.java' ')' -exec chmod a-x {} ';'
 cd ..
